#
# spec file for package python-zope.testrunner
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-zope.testrunner
Version:        4.7.0
Release:        lp151.2.2
Summary:        Zope testrunner script
License:        ZPL-2.1
Group:          Development/Languages/Python
Url:            https://pypi.python.org/pypi/zope.testrunner
Source:         https://files.pythonhosted.org/packages/source/z/zope.testrunner/zope.testrunner-%{version}.zip
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
# runtime requirements:
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module zope.exceptions}
BuildRequires:  %{python_module zope.interface}
# Test requirements:
BuildRequires:  %{python_module zope.testing}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires:       python-six
Requires:       python-zope.exceptions
Requires:       python-zope.interface
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%python_subpackages

%description
This package provides a flexible test runner with layer support.

%prep
%setup -q -n zope.testrunner-%{version}
find -size 0 -delete

%build
%python_build

%install
%python_install
%python_expand %fdupes -s %{buildroot}%{$python_sitelib}

%python_clone -a %{buildroot}%{_bindir}/zope-testrunner

# Can't seem to be able to run the tests with an uninstalled zope.testrunner
#%%check
#%%python_exec setup.py test

%post
%python_install_alternative zope-testrunner

%postun
%python_uninstall_alternative zope-testrunner

%files %{python_files}
%defattr(-,root,root,-)
%doc LICENSE.rst README.rst
%python_alternative %{_bindir}/zope-testrunner
%{python_sitelib}/*

%changelog
* Thu Jun 29 2017 aloisio@gmx.com
- Added missing requires for update-alternatives
* Fri Jun 23 2017 aloisio@gmx.com
- Update to 4.7.0
  * Drop all support for ``subunit``.
  4.6.0:
  * Make the ``subunit`` support purely optional: applications
    which have been getting the dependencies via
    ``zope.testrunner`` should either add
    ``zope.testrunner[subunit]`` to their ``install_requires`` or
    else depend directly on ``python-subunit``.
  * New option ``--ignore-new-thread=<regexp>`` to suppress
    "New thread(s)" warnings.
  * Support Python 3.6.
  4.5.1:
  * Fixed: Using the ``-j`` option to run tests in multiple
    processes caused tests that used the ``multiprocessing``
    package to hang (because the testrunner replaced ``sys.stdin``
    with an unclosable object).
  * Drop conditional dependency on ``unittest2`` (redundant after
    dropping support for Python 2.6).
  4.5.0:
  * Stop tests for all layers when test fails/errors when started
    with -x/--stop-on-error
    (`#37 <https://github.com/zopefoundation/zope.testrunner/pull/37>`_).
  * Drop support for Python 2.6 and 3.2.
  4.4.10:
  * Add support for Python 3.5
    (`#31 <https://github.com/zopefoundation/zope.testrunner/pull/31>`_).
  * Insert extra paths (from ``--path``) to the front of sys.argv
    (`#32 <https://github.com/zopefoundation/zope.testrunner/issues/32>`_).
  4.4.9:
  * When using ``-j``, parallelize all the tests, including the
    first test layer
    (`#28 <https://github.com/zopefoundation/zope.testrunner/issues/28>`_).
- Converted to single-spec
* Mon Aug 15 2016 toddrme2178@gmail.com
- Fix update-alternatives implementation.
* Fri May 15 2015 benoit.monin@gmx.fr
- update to version 4.4.8:
  * Support skipped tests in subunit output
  * More efficient test filtering
- additional changes from version 4.4.7:
  * Work around a bug in PyPy3’s curses module (#24).
- additional changes from version 4.4.6:
  * Restore support for instance-based test layers that regressed
    in 4.4.5 (#20).
- additional changes from version 4.4.5:
  * Sort related layers close to each other to reduce the number of
    unnecessary teardowns (fixes #14).
  * Run the unit test layer first (fixes LP #497871).
- additional changes from version 4.4.4:
  * When looking for the right location of test code, start with
    longest location paths first. This fixes problems with nested
    code locations.
- additional changes from version 4.4.3:
  * Added support for Python 3.4.
- additional changes from version 4.4.2:
  * Drop support for Python 3.1.
  * Fix post-mortem debugging when a non-printable exception
    happens (#8).
- add runtime requirements python-six, python-zope.exceptions,
  python-zope.interface
- update the test requirements (still commented out, tests fail)
- fix update-alternatives
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashism in pre script
* Thu Nov 14 2013 p.drouand@gmail.com
- Add update-alternative support
* Wed Nov 13 2013 p.drouand@gmail.com
- Update to version 4.4.1
  + Updated boostrap.py to version 2.2.
  + Fix nondeterministic test failures on Python 3.3
  + Tear down layers after post_mortem debugging is finished.
  + Fix tests that write to source directory, it might be read-only.
- Changes from 4.4.0
  + Fix tests selection when the negative "!" pattern is used several times
    (LP #1160965)
  +  Moved tests into a 'tests' subpackage.
  + Made python -m zope.testrunner work again.
  + Support 'skip' feature of unittest2 (which became the new unittest in Python 2.7).
  + Better diagnostics when communication with subprocess fails
    (https://github.com/zopefoundation/zope.testrunner/issues/5).
  + Do not break subprocess execution when the test suite changes the working
    directory (https://github.com/zopefoundation/zope.testrunner/issues/6).
  + Count test module import errors as errors (LP #1026576).
- Add python-unittest2 and python-zope.interface commented BuildRequires;
  these are new requirements for test but there are still broken
- Add fdupes BuildRequires and use fdupes to remove duplicate files
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Fri Mar 15 2013 speilicke@suse.com
- Initial version
